@@ -35,8 +35,8 @@ def log_info():
 
 
 class StdErrHandler(logging.StreamHandler):
-    #: Log levels that we use throughout the code (python defaults) mapped to numerical counterparts used in syslog/systemd
-    SYSTEMD_PREFIX = {} if sys.stderr.isatty() else {
+    #: Maps python log levels to systemd prefix counterparts
+    SYSTEMD_PREFIX = {
         logging.getLevelNamesMapping()["CRITICAL"]: "<2>",
         logging.getLevelNamesMapping()["ERROR"]: "<3>",
         logging.getLevelNamesMapping()["WARNING"]: "<4>",
@@ -44,12 +44,12 @@ class StdErrHandler(logging.StreamHandler):
         logging.getLevelNamesMapping()["DEBUG"]: "<7>",
     }
 
-    #: Generic log format
-    LOG_FORMAT = "{systemd_prefix}{levelname[0]}: {message} [{threadName}({thread}), {name}({filename}:{lineno})]"
+    #: Generic message format
+    MSG_FORMAT = "{levelname[0]}: {message} [{threadName}({thread}), {name}({filename}:{lineno})]"
 
-    def __init__(self):
+    def __init__(self, log_systemd=False, log_stamp=False):
         super().__init__(stream=sys.stderr)
-        self.setFormatter(logging.Formatter(self.LOG_FORMAT, style="{"))
+        self.setFormatter(logging.Formatter(f"{'{systemd_prefix}' if log_systemd else ''}{'{asctime} ' if log_stamp else ''}{self.MSG_FORMAT}", style="{"))
 
     def emit(self, record):
         record.systemd_prefix = self.SYSTEMD_PREFIX.get(record.levelno, "")
@@ -134,6 +134,11 @@ class CLI():
                                      "May also be given as ``<logger>.<level>`` to effect individual loggers only,\n"
                                      "and multiple times (check existing logs for actual logger names)."
                                  )).completer = CLI.log_level_completer
+        self.parser.add_argument("--log-stamp", action="store_true",
+                                 help="prefix each log line with a timestamp")
+        self.parser.add_argument("--log-systemd", action="store_true",
+                                 help="prefix logs for systemd (recognize log level)")
+
         if run_as_mini_buildd:
             self.parser.add_argument("-U", "--dedicated-user", action="store", default="mini-buildd",
                                      help="Force a custom dedicated user name (to run as a different user than 'mini-buildd').")
@@ -160,7 +165,7 @@ class CLI():
         if self.args.log_level is None:
             self.args.log_level = self.LOG_LEVEL_DEFAULT
 
-        logging.root.handlers = [StdErrHandler()]
+        logging.root.handlers = [StdErrHandler(log_systemd=self.args.log_systemd, log_stamp=self.args.log_stamp)]
         for log_level in self.args.log_level:
             self.log_level_parse(log_level, set_level=True)
 
