@@ -47,7 +47,7 @@ import re
 import subprocess
 import time
 
-from mini_buildd import call, config, files, util
+from mini_buildd import call, config, dist, files, util
 
 LOG = logging.getLogger(__name__)
 
@@ -87,7 +87,7 @@ class Blocks(files.Dir):
         header = (
             f"Ordered sbuild {self.type} blocks (space-separated)\n"
             "\n"
-            f"Default if not given: {self.default}\n\n"
+            f"Default: {self.default}\n\n"
             "Available blocks:\n\n"
         )
         ml = max(len(name) for name in self.keys())  # "max length" formatting helper
@@ -109,7 +109,7 @@ class Blocks(files.Dir):
 class ConfigBlocks(Blocks):
     def __init__(self):
         super().__init__("config")
-        self.default = "set-default-path ccache"
+        self.default = dist.SETUP["defaults"]["distribution"]["sbuild_config_blocks"]
 
     def configure(self, file_, blocks):
         """Add configured blocks to provided file"""
@@ -120,7 +120,7 @@ class ConfigBlocks(Blocks):
 class SetupBlocks(Blocks):
     def __init__(self):
         super().__init__("setup")
-        self.default = "apt-setup apt-update ccache eatmydata"
+        self.default = dist.SETUP["defaults"]["distribution"]["sbuild_setup_blocks"]
 
     def configure(self, dir_, blocks):
         """Add configured blocks to provided dir"""
@@ -412,8 +412,9 @@ class SBuild():
         lintian_check = self.breq.check_mode("lintian")
         if lintian_check.mode.value > 0:
             cmdline += ["--run-lintian"]
-            cmdline += ["--lintian-opts", lintian_check.lintian_options(self.breq.dist.codename)]
             cmdline += ["--lintian-opts", self.breq.check_extra_options("lintian")]
+            if lintian_check.mode == lintian_check.Mode.WARNFAIL:
+                cmdline += ["--lintian-opts", self.breq.cget("Lintian-Warnfail-Options")]
         else:
             cmdline += ["--no-run-lintian"]
 
@@ -455,7 +456,7 @@ class SBuild():
                 env=call.taint_env(env),
                 stdout=buildlog,
                 stderr=subprocess.STDOUT) as self.call:
-            LOG.info("%s: Running sbuild from %s (pid=%s)", self.breq, self.breq.dir_path(), self.call.pid)
+            LOG.debug("%s: Running sbuild from %s (pid=%s)", self.breq, self.breq.dir_path(), self.call.pid)
             retval = self.call.wait()
 
         # Update bres from buildlog
@@ -463,9 +464,11 @@ class SBuild():
         with util.fopen(buildlog_file_path, errors="replace") as f:
             for line in f:
                 if self.BUILDLOG_STATUS_REGEX.match(line):
+                    # Example sbuild >= 0.91: "Lintian: successful (worst tag: warn)" (previously, there was no appendix)
                     LOG.debug("Build log line detected as build status: %s", line.strip())
-                    s = line.split(":")
-                    self.bres.cset("Sbuild-" + s[0], s[1].strip())
+                    key, _dummy, value = line.partition(":")
+                    status = value.strip().partition(" ")[0]  # As lintian now (sbuild 0.91) has potential appendix, we need to use 1st word only as raw status
+                    self.bres.cset("Sbuild-" + key, status)
 
         # Guarantee to set 'error' sbuild status if retval != 0 and 'Sbuild-Status' could not be parsed from buildlog
         if retval != 0 and not self.bres.cget("Sbuild-Status"):
