@@ -137,7 +137,9 @@ class HTTPUnavailable(HTTPError):
         super().__init__(http.HTTPStatus.SERVICE_UNAVAILABLE, detail)
 
 
-HTTPShutdown = HTTPUnavailable("Server Shutdown")
+class HTTPShutdown(HTTPUnavailable):
+    def __init__(self, detail=None):
+        super().__init__("Server Shutdown")
 
 
 class HTTPInternal(HTTPError):
